@@ -1,22 +1,22 @@
 """Get information from GCE Ecodevices RT2."""
-
-from .ecodevices_rt2 import EcoDevicesRT2
-from .abstractswitch import AbstractSwitch
+from .ecodevices_rt2 import EcoDevicesRT2  # noreorder
 from .abstractsensor import AbstractSensor
-from .enocean import EnOceanSwitch, EnOceanSensor
-from .toroid import Toroid
-from .relay import Relay
-from .virtualoutput import VirtualOutput
-from .digitalinput import DigitalInput
-from .xthl import XTHL
-from .x4fp import X4FP
+from .abstractswitch import AbstractSwitch
 from .counter import Counter
-from .supplierindex import SupplierIndex
+from .digitalinput import DigitalInput
+from .enocean import EnOceanSensor
+from .enocean import EnOceanSwitch
 from .post import Post
+from .relay import Relay
+from .supplierindex import SupplierIndex
+from .toroid import Toroid
+from .virtualoutput import VirtualOutput
+from .x4fp import X4FP
+from .xthl import XTHL
 
 __author__ = """Pierre COURBIN"""
-__email__ = 'pierre.courbin@gmail.com'
-__version__ = '1.1.0'
+__email__ = "pierre.courbin@gmail.com"
+__version__ = "1.3.2"
 
 __all__ = [
     "EcoDevicesRT2",
@@ -32,5 +32,5 @@ __all__ = [
     "X4FP",
     "Counter",
     "SupplierIndex",
-    "Post"
+    "Post",
 ]
